@@ -13,6 +13,7 @@ import urllib.request as request
 import time
 import importlib
 import copy
+import ssl
 from yaml import load, dump
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
@@ -220,8 +221,9 @@ def prepare_dir(args):
         task_url = args.amis_file.replace('push','task')
         task_url = task_url.replace('https','http')
         json_url = task_url + "/log/images.json?format=raw"
+        context = ssl._create_unverified_context()
         print('Get data from %s' % json_url)
-        s = request.urlopen(json_url)
+        s = request.urlopen(json_url,context=context)
         print('Got data from %s' % s.geturl())
         task_id = task_url.rstrip('/').split('/')[-1]
         logdir = "{}_{}".format(logdir, task_id)
@@ -372,7 +374,7 @@ def run_cmd(test_instance,
 
     try:
         if test_instance.ssh_client is not None:
-            status, output = rmt_ssh.remote_excute(test_instance.ssh_client, cmd, timeout, redirect_stdout=rmt_redirect_stdout, redirect_stderr=rmt_redirect_stderr,rmt_get_pty=rmt_get_pty, log=test_instance.log)
+            status, output = rmt_ssh.remote_excute(test_instance.ssh_client, cmd, timeout, redirect_stdout=rmt_redirect_stderr, redirect_stderr=rmt_redirect_stdout,rmt_get_pty=rmt_get_pty, log=test_instance.log)
         else:
             ret = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, timeout=timeout, encoding='utf-8')
             status = ret.returncode
@@ -511,18 +513,21 @@ def getboottime(test_instance):
             break
         time_end = int(time.time())
         run_cmd(test_instance, 'sudo systemctl list-jobs')
-        if time_end - time_start > 60:
-            test_instance.fail("Bootup is not yet finished after 60s")
+        if time_end - time_start > 120:
+            test_instance.fail("Bootup is not yet finished after 120s")
         test_instance.log.info("Wait for bootup finish......")
-        time.sleep(1)
+        time.sleep(2)
     cmd = "sudo systemd-analyze blame > /tmp/blame.log"
     run_cmd(test_instance, cmd, expect_ret=0)
     run_cmd(test_instance, "cat /tmp/blame.log", expect_ret=0)
     output = run_cmd(test_instance, "sudo systemd-analyze", expect_ret=0)
     boot_time = re.findall("=.*s", output)[0]
     boot_time = boot_time.strip("=\n")
-    boot_time_sec = re.findall('[0-9.]+s', boot_time)[0]
-    boot_time_sec = boot_time_sec.strip('= s')
+    boot_time_sec = re.findall('[0-9.]+s', boot_time)
+    if len(boot_time_sec) == 0:
+        boot_time_sec = 0
+    else:
+        boot_time_sec = boot_time_sec[0].strip('= s')
     if 'min' in boot_time:
         boot_time_min = re.findall('[0-9]+min', boot_time)[0]
         boot_time_min = boot_time_min.strip('min')
